@@ -9,7 +9,7 @@ DEFAULT_HOST_INSTANCE = None
 
 activateDB = OS.get_os_variable("ACTIVATE_DATABASE", default=False, toBool=True)
 
-if activateDB:
+if not activateDB:
     if not DEFAULT_HOST_INSTANCE:
         DEFAULT_HOST_INSTANCE = MCore().constructor()
         try:
